.. scud documentation master file, created by
   sphinx-quickstart on Sun Jan  7 17:02:53 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to scud's documentation!
=====================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   ./inference.rst
   ./sampling.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
